@@ -4,7 +4,7 @@
 // Description:
 //
 //
-// Author: Hans Oischinger <oisch@users.berlios.de>, (C) 2004
+// Author: Hans Oischinger <hans.oischinger@kde-mail.net>, (C) 2004
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -30,6 +30,7 @@
 #include <kaboutapplication.h>
 #include <ksharedpixmap.h>
 #include <kwinmodule.h>
+#include <kdebug.h>
 #include <dcopclient.h>
 #include <dcopref.h>
 
@@ -62,7 +63,7 @@ KomposeGlobal* KomposeGlobal::instance()
 {
   if ( !globalInstance )
   {
-    qDebug("KomposeSettings::instance() - Creating Singleton instance");
+    kdDebug() << "KomposeSettings::instance() - Creating Singleton instance" << endl;
     KomposeGlobal *settiglobalInstance = new KomposeGlobal();
   }
   return globalInstance;
@@ -70,11 +71,11 @@ KomposeGlobal* KomposeGlobal::instance()
 
 KomposeGlobal::KomposeGlobal(QObject *parent, const char *name)
     : QObject(parent, name),
+    aboutDialogOpen(0),
     hideSystray( false ),
     singleShot( false ),
     xcomposite(0),
-    damageEvent(0),
-    aboutDialogOpen(0)
+    damageEvent(0)
 {
   globalInstance = this;
   kwin_module = new KWinModule(); //FIXME: only needed for sharedpixmap :(
@@ -86,7 +87,7 @@ KomposeGlobal::KomposeGlobal(QObject *parent, const char *name)
   initCompositeExt();
   initImlib();
 
-  connect( KomposeSettings::instance(), SIGNAL(settingsChanged()), this, SLOT(initCompositeExt()) );
+  connect( KomposeSettings::instance(), SIGNAL(settingsChanged()), this, SLOT(slotConfigChanged()) );
 }
 
 KomposeGlobal::~KomposeGlobal()
@@ -103,9 +104,14 @@ KomposeGlobal::~KomposeGlobal()
   delete desktopBgPixmap;
 }
 
+void KomposeGlobal::slotConfigChanged( )
+{
+  initCompositeExt();
+}
+
 /**
  * Gives us control about when the GUI should appear. Called from outside
- * Called from outside as KkomposeGlobal is a singleton that can be instantiated at any time
+ * Called from outside as KomposeGlobal is a singleton that can be instantiated at any time
  */
 void KomposeGlobal::initGui()
 {
@@ -124,17 +130,17 @@ void KomposeGlobal::initGui()
     // Create systray
     systray = new KomposeSysTray();
     kapp->setMainWidget( systray );
-    systray->setPixmap( systray->loadIcon( "kompose" ) );
+    systray->currentDesktopChanged( currentDesktop );
 
     actionCollection->setWidget( systray );
     systray->show();
   }
   else
-    qDebug("KomposeGlobal::initGui() - Hiding systray icon");
+    kdDebug() << "KomposeGlobal::initGui() - Hiding systray icon" << endl;
 
   if ( singleShot )
   {
-    qDebug("KomposeGlobal::initGui() - SingleShot has been selected");
+    kdDebug() << "KomposeGlobal::initGui() - SingleShot has been selected" << endl;
     KomposeViewManager::instance()->createView();
   }
 }
@@ -149,15 +155,15 @@ void KomposeGlobal::initActions()
 
   // Actions
   actQuit = KStdAction::quit( kapp, SLOT(quit()), actionCollection );
-  actShowWorldView = new KAction(i18n("Komposé (ungrouped)"), "kompose",
+  actShowWorldView = new KAction(i18n("Komposé (ungrouped)"), "kompose_ungrouped",
                                  0,
                                  KomposeViewManager::instance(), SLOT(createWorldView()),
                                  actionCollection, "showWorldView");
-  actShowVirtualDesktopView = new KAction(i18n("Komposé (grouped by virtual desktops)"), "kompose",
+  actShowVirtualDesktopView = new KAction(i18n("Komposé (grouped by virtual desktops)"), "kompose_grouped_by_virtual_desktop",
                                           0,
                                           KomposeViewManager::instance(), SLOT(createVirtualDesktopView()),
                                           actionCollection, "showVirtualDesktopView");
-  actShowCurrentDesktopView = new KAction(i18n("Komposé (current virtual desktop)"), "kompose",
+  actShowCurrentDesktopView = new KAction(i18n("Komposé (current virtual desktop)"), "kompose_current_virtual_desktop",
                                           0,
                                           KomposeViewManager::instance(), SLOT(createCurrentDesktopView()),
                                           actionCollection, "showCurrentDesktopView");
@@ -191,12 +197,13 @@ void KomposeGlobal::initSharedPixmaps()
     //return;
   }
 
-  qDebug("KomposeGlobal::initSharedPixmaps()");
+  kdDebug() << "KomposeGlobal::initSharedPixmaps()" << endl;
   refreshSharedPixmaps();
 }
 
 void KomposeGlobal::slotDesktopChanged(int desktop)
 {
+  systray->currentDesktopChanged( desktop );
   if (desktop != -2)
   {
     // -2 is for manual loading, everything else enables the following checks:
@@ -212,7 +219,7 @@ void KomposeGlobal::slotDesktopChanged(int desktop)
   refreshSharedPixmaps();
 }
 
-void KomposeGlobal::slotBackgroundChanged(int desktop)
+void KomposeGlobal::slotBackgroundChanged(int)
 {
   refreshSharedPixmaps();
 }
@@ -238,7 +245,7 @@ void KomposeGlobal::slotDone(bool success)
 {
   if (!success)
   {
-    qDebug("KomposeGlobal::slotDone() - loading of desktop background failed.\n");
+    kdDebug() << "KomposeGlobal::slotDone() - loading of desktop background failed.\n" << endl;
     //QTimer::singleShot( 1000, this, SLOT( initSharedPixmaps() ) );
   }
 }
@@ -246,7 +253,7 @@ void KomposeGlobal::slotDone(bool success)
 void KomposeGlobal::enablePixmapExports()
 {
 #ifdef Q_WS_X11
-  qDebug("KomposeGlobal::enablePixmapExports()");
+  kdDebug() << "KomposeGlobal::enablePixmapExports()" << endl;
   DCOPClient *client = kapp->dcopClient();
   if (!client->isAttached())
     client->attach();
@@ -293,7 +300,7 @@ void KomposeGlobal::initImlib()
   Display *disp;
   Visual *vis;
   Colormap cm;
-  int screen;
+  //int screen;
   disp = QPaintDevice::x11AppDisplay();
   vis   = DefaultVisual(disp, DefaultScreen(disp));
   cm    = DefaultColormap(disp, DefaultScreen(disp));
@@ -306,7 +313,7 @@ void KomposeGlobal::initImlib()
   imlib_context_set_display(disp);
   imlib_context_set_visual(vis);
   imlib_context_set_colormap(cm);
-  qDebug("KomposeGlobal::initImlib() - Imlib2 support enabled.");
+  kdDebug() << "KomposeGlobal::initImlib() - Imlib2 support enabled." << endl;
 }
 
 /**
@@ -335,7 +342,7 @@ void KomposeGlobal::initCompositeExt()
     // major and minor will now contain the version the server supports.
     if (!(major > 0 || minor >= 2))
     {
-      qDebug("KomposeGlobal::initCompositeExt() - XComposite doesn't allow NamePixmap requests! - Disabling XComposite support");
+      kdDebug() << "KomposeGlobal::initCompositeExt() - XComposite doesn't allow NamePixmap requests! - Disabling XComposite support" << endl;
       // TODO: create a namewindowpixbool to make it work with composite 0.1
       xcomposite = false;
     }
@@ -344,14 +351,14 @@ void KomposeGlobal::initCompositeExt()
     int renderEvent, renderError;
     if (!XRenderQueryExtension (dpy, &renderEvent, &renderError))
     {
-      qDebug("KomposeGlobal::initCompositeExt() - XRender not available! - Disabling XComposite support");
+      kdDebug() << "KomposeGlobal::initCompositeExt() - XRender not available! - Disabling XComposite support" << endl;
     }
 
     //XDamage version check
     //int damageEvent, damageError; // The event base is important here
     if (!XDamageQueryExtension( dpy, &damageEvent, &damageError ))
     {
-      qDebug("KomposeGlobal::initCompositeExt() - XDamage is not available! - Disabling XComposite support");
+      kdDebug() << "KomposeGlobal::initCompositeExt() - XDamage is not available! - Disabling XComposite support" << endl;
       xcomposite = false;
     }
 
@@ -361,7 +368,8 @@ void KomposeGlobal::initCompositeExt()
 #endif
 
   if ( xcomposite )
-    qDebug("KomposeGlobal::initCompositeExt() - XComposite extension found and enabled.");
+    kdDebug() << "KomposeGlobal::initCompositeExt() - XComposite extension found and enabled." << endl;
 }
 
+
 #include "komposeglobal.moc"
